---
title: "Steampipe Table: splunk_token - Query Splunk Tokens using SQL"
description: "Allows users to query Tokens in Splunk, specifically the unique identifiers, providing insights into token usage and potential security risks."
---

# Table: splunk_token - Query Splunk Tokens using SQL

Splunk is a software platform that provides real-time data processing capabilities and data visualization. It allows users to search, analyze, and visualize the raw data generated by their organization's IT infrastructure. A Splunk Token is a unique identifier used for authentication and authorization within the Splunk platform.

## Table Usage Guide

The `splunk_token` table provides insights into Tokens within Splunk. As a security analyst, explore token-specific details through this table, including token identifiers, creation time, and associated metadata. Utilize it to uncover information about tokens, such as their usage, potential security risks, and the verification of token permissions.

## Examples

### Basic info
Explore the status and issuer of various tokens, along with their expiration times, to better manage and monitor your token usage. This helps to maintain system security and ensures tokens are renewed or removed before they expire.

```sql+postgres
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token;
```

```sql+sqlite
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token;
```

### List disabled tokens
Explore which tokens have been disabled in your system to ensure that no unauthorized access can occur. This can help in maintaining security and preventing potential data breaches.

```sql+postgres
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  status = 'disabled';
```

```sql+sqlite
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  status = 'disabled';
```

### List unused tokens
Identify instances where certain tokens have never been used. This can help in managing and deactivating unnecessary tokens, thereby enhancing system security.

```sql+postgres
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  last_used is null;
```

```sql+sqlite
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  last_used is null;
```

### List expired tokens
Determine the areas in which security tokens have already expired. This query is useful for identifying potential vulnerabilities and ensuring prompt renewal or removal of these expired tokens.

```sql+postgres
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  now()::timestamp > expiration_time;
```

```sql+sqlite
select
  name,
  status,
  issuer,
  expiration_time
from
  splunk_token
where
  datetime('now') > expiration_time;
```